# mobile_modem_exporter
Prometheus exporter for mobile modems (LTE/GSM) written in Python

[![Build Status](https://api.travis-ci.com/tykling/mobile_modem_exporter.svg?branch=main)](https://travis-ci.com/github/tykling/mobile_modem_exporter)
[![codecov](https://codecov.io/gh/tykling/mobile_modem_exporter/branch/master/graph/badge.svg)](https://codecov.io/gh/tykling/mobile_modem_exporter)
[![Language grade: Python](https://img.shields.io/lgtm/grade/python/g/tykling/mobile_modem_exporter.svg?logo=lgtm&logoWidth=18)](https://lgtm.com/projects/g/tykling/mobile_modem_exporter/context:python)
[![Checked with mypy](docs/badges/mypy_badge.svg)](http://mypy-lang.org/)
[![Checked with flake8](docs/badges/flake8-OK-green.svg)](http://flake8.pycqa.org/en/latest/)
[![Codestyle black](docs/badges/black.svg)](https://github.com/psf/black/)
[![PyPI](https://img.shields.io/pypi/v/mobile_modem_exporter.svg)](https://pypi.org/project/mobile_modem_exporter/)
[![PyPI downloads](https://img.shields.io/pypi/dm/mobile_modem_exporter.svg)](https://pypi.org/project/mobile_modem_exporter/)
